@@ -28,8 +28,10 @@ public:
 
 class YTextProperty : public XTextProperty {
 public:
-    YTextProperty(const char* str);
+    YTextProperty(const char* str = nullptr);
+    YTextProperty(Window handle, Atom property);
     ~YTextProperty();
+    operator const char*() const { return (const char *) value; }
 };
 
 enum YFormat { F8 = 8, F16 = 16, F32 = 32 };
@@ -110,10 +112,9 @@ public:
     int displayHeight() { return DisplayHeight(display(), screen()); }
     Atom atom(const char* name) { return XInternAtom(display(), name, False); }
     void sync() const { XSync(display(), False); }
-    void send(XClientMessageEvent& ev, Window win, long mask = NoEventMask) const {
-        XSendEvent(display(), win, False, mask,
-                   reinterpret_cast<XEvent*>(&ev));
-    }
+    void send(XClientMessageEvent& ev, Window win, long mask = NoEventMask) const;
+    Window parent(Window child) const;
+    bool children(Window win, Window** data, unsigned* num) const;
 
     bool hasColormap() const { return fHasColormaps; }
     bool synchronized() const { return synchronizeX11; }
